@@ -10,7 +10,7 @@ attributesReassign <- function(atts, obj) {
   obj
 }
 
-knownAtts <- c("cpp", "class", "attributes", "values", "definition", "pnt")
+knownAtts <- c("cpp", "class", "attributes", "values", "definition", "pnt", "ptr")
 
 ## non-exported tag stuff -------------------------------------------------------
 
@@ -389,9 +389,10 @@ setMethod(
     if (isTRUE(fromMemoise)) {
       whMessage <- .message$LoadedCacheResult(2)
     } else if (fromMemoise %in% FALSE) {
-      postMess <- paste0(" ", .message$AddingToMemoised)
+      if (isTRUE(getOption("reproducible.useMemoise")))
+        postMess <- paste0(" ", .message$AddingToMemoised)
     }
-    baseMess <- .message$LoadedCache(whMessage, functionName)
+    baseMess <- .message$LoadedCache(whMessage, .messageFunctionFn(functionName)) # ELIOT HERE
     if (!is.null(postMess))
       baseMess <- paste0(baseMess, postMess)
     messageCache(baseMess, verbose = verbose)
@@ -419,7 +420,7 @@ setMethod(
   fileFormat <- unique(extractFromCache(fullCacheTableForObj, elem = "fileFormat")) # can have a single tif for many entries
 
   messageCache(.message$ObjToRetrieveFn(functionName), ", ",
-  #             messageCache("...(Object to retrieve (fn: ", .messageFunctionFn(functionName), ", ",
+               #             messageCache("...(Object to retrieve (fn: ", .messageFunctionFn(functionName), ", ",
                basename2(CacheStoredFile(cachePath, cacheId, format = fileFormat)),
                ")",
                if (bigFile) " is large: ",
@@ -685,7 +686,11 @@ remapFilenames <- function(obj, tags, cachePath, ...) {
       }
     }
     newName <- vapply(origRelName, function(x) {
-      fs::path_join(c(absBase, x)) |> fs::path_norm()
+      if (fs::is_absolute_path(x)) {
+        x
+      } else {
+        fs::path_join(c(absBase, x)) |> fs::path_norm()
+      }
     }, character(1))
   } else {
     newName <- obj
@@ -908,14 +913,14 @@ unmakeMemoisable.default <- function(x) {
   obj <- lapply(obj, .wrap, preDigest = preDigest, cachePath = cachePath, drv = drv,
                 conn = conn, verbose = verbose, ...)
   hasTagAttr <- lapply(obj, function(x) attr(x, "tags"))
-  tagAttr <- list(unlist(hasTagAttr))
+  tagAttr <- unname(unlist(hasTagAttr)) # this removed name
   if (length(tagAttr)) {
     if (is.null(attrsOrig[["tags"]])) {
       newList <- tagAttr
     } else {
-      newList <- try(modifyList(attrsOrig["tags"], tagAttr))
+      newList <- try(c(attrsOrig[["tags"]], tagAttr))
     }
-    attrsOrig["tags"] <- newList
+    attrsOrig[["tags"]] <- newList
   }
   if (!is.null(attrsOrig)) {
     for (tt in intersect(names(attrsOrig), c(".Cache", "tags", "call")))
@@ -937,9 +942,9 @@ unmakeMemoisable.default <- function(x) {
   }
 
   if (length(ls(obj, all.names = T)) > 0) {
-  obj2 <- as.list(obj, all.names = TRUE)
-  out <- .wrap(obj2, cachePath = cachePath, preDigest = preDigest, drv = drv,
-               conn = conn, verbose = verbose, outputObjects = outputObjects, ...)
+    obj2 <- as.list(obj, all.names = TRUE)
+    out <- .wrap(obj2, cachePath = cachePath, preDigest = preDigest, drv = drv,
+                 conn = conn, verbose = verbose, outputObjects = outputObjects, ...)
     # obj <- Copy(obj)
     obj2 <- list2envAttempts(out, obj)
     if (!is.null(obj2)) obj <- obj2
@@ -964,7 +969,6 @@ unmakeMemoisable.default <- function(x) {
   rasters <- is(obj, "Raster")
   atts <- attributes(obj)
   reassignAtts <- TRUE
-
   if (any(rasters)) {
     .requireNamespace("raster", stopOnFALSE = TRUE)
     objOrig <- obj
@@ -1041,7 +1045,7 @@ unmakeMemoisable.default <- function(x) {
         xmin = terra::xmin(obj), xmax = terra::xmax(obj),
         ymin = terra::ymin(obj), ymax = terra::ymax(obj)
       )
-      attr(obj, "class") <- "PackedSpatExtent"
+      attr(obj, "class") <- "PackedSpatExtent2"
       useWrap <- FALSE
       reassignAtts <- FALSE
     }
@@ -1076,13 +1080,13 @@ unmakeMemoisable.default <- function(x) {
     obj <- lapply(obj, .unwrap)
     obj <- terra::svc(obj)
   }
-  if (any(inherits(obj, c("PackedSpatVector", "PackedSpatRaster", "PackedSpatExtent")))) {
+  if (any(inherits(obj, c("PackedSpatVector", "PackedSpatRaster", "PackedSpatExtent2")))) {
     if (!requireNamespace("terra")) stop("Please install.packages('terra')")
     if (any(inherits(obj, "PackedSpatVector"))) {
       obj <- terra::vect(obj)
     } else if (any(inherits(obj, "PackedSpatRaster"))) {
       obj <- terra::rast(obj)
-    } else if (any(inherits(obj, "PackedSpatExtent"))) {
+    } else if (any(inherits(obj, "PackedSpatExtent2"))) {
       obj <- terra::ext(unlist(obj))
     }
   } else if (any(inherits(obj, "data.table"))) {
