@@ -121,6 +121,19 @@
 #'   \item{`showSimilar`}{
 #'     Default `FALSE`. Passed to `Cache`.
 #'   }
+#'   \item{`testCharacterAsFile`}{
+#'     Default `FALSE`. The behaviour of `.robustDigest` on `character` vectors prior to
+#'     `reproducible == 2.1.2` was that the function would test for whether they were
+#'     filenames by using `file.exists`. If it was a filename, then it would digest
+#'     the file content. In cases of a character vector or a data.frame of "filenames",
+#'     this could cause long hanging of the R system as it tries to digest the file
+#'     contents of potentially many files. This behaviour is not transparent to a user.
+#'     Now the default is to **not** digest the file content of a `character` vector
+#'     even if they are filenames. To force file content digesting, then convert to
+#'     either `asPath` or `fs::as_fs_path`. Or set this option to `TRUE` and the previous
+#'     behaviour will return, where it tries to guess whether a character vector
+#'     is filenames or not, and if it is, then digest the file content.
+#'   }
 #'   \item{`timeout`}{
 #'     Default `1200`. Used in `preProcess` when downloading occurs. If a user has `R.utils`
 #'     package installed, `R.utils::withTimeout(  , timeout = getOption("reproducible.timeout"))`
@@ -252,12 +265,16 @@ reproducibleOptions <- function() {
     reproducible.showSimilar = FALSE,
     reproducible.showSimilarDepth = 3,
     reproducible.tempPath = file.path(tempdir(), "reproducible"),
+    reproducible.testCharacterAsFile = FALSE,
     reproducible.timeout = 1200,
     reproducible.useCache = TRUE, # override Cache function
     reproducible.useCloud = FALSE, #
-    reproducible.useDBI = {getEnv("R_REPRODUCIBLE_USE_DBI",
-      default = useDBI(getOption("reproducible.useDBI", NULL),  # a user may have set it before this runs; keep setting
-                       verbose = interactive() - (useDBI() + 1)), # `FALSE` is useMultipleDBFiles now
+    reproducible.useDBI = {
+      getEnv("R_REPRODUCIBLE_USE_DBI",
+      default = {
+        useDBI(getOption("reproducible.useDBI", NULL),  # a user may have set it before this runs; keep setting
+                       verbose = interactive() - (useDBI() + 1), default = TRUE)
+        }, # `FALSE` is useMultipleDBFiles now
       allowed = c("true", "false")
     ) |> as.logical()},
     reproducible.useGdown = FALSE,
