@@ -27,11 +27,7 @@ test_that("test file-backed raster caching", {
   #   solves the error about not being in the testthat package
   val1 <- .cacheNumDefaultTags() + length(tagsSpatRaster()) # adding a userTag here... the +8 is the SpatRaster extras
   ik <- .ignoreTagKeys()
-  # with_mock(
-  #   "reproducible::isInteractive" = function() TRUE,
-  #   {
   aa <- Cache(randomPolyToDisk, tmpfile[1], cachePath = tmpCache, userTags = "something2")
-  # Test clearCache by tags
 
   expect_equal(NROW(showCache(tmpCache)[!tagKey %in% .ignoreTagKeys()]), val1)
   clearCache(tmpCache, userTags = "something$", ask = FALSE)
@@ -60,7 +56,7 @@ test_that("test file-backed raster caching", {
         basename(tmpfile[1])
       ), split = "[\\/]")
     ))
-    expect_true(any(grepl(
+    expect_true(any(cli::ansi_grepl(
       pattern = basename(tmpfile[1]),
       dir(file.path(tmpCache, "rasters"))
     )))
@@ -91,7 +87,7 @@ test_that("test file-backed raster caching", {
   # ._prepareOutputs_1 <<- ._prepareOutputs_2 <<- ._getFromRepo <<- 1
   # Will silently update the filename of the RasterLayer, and recover it
   type <- gsub("Connection", "", class(getOption("reproducible.conn")))
-  isSQLite <- grepl(type, "NULL")
+  isSQLite <- cli::ansi_grepl(type, "NULL")
   if (!isSQLite) {
     warn1 <- capture_warnings(movedCache(tmpdir, old = tmpCache))
   }
@@ -349,7 +345,7 @@ test_that("test 'quick' argument", {
     out1c <- Cache(quickFun, thePath, cachePath = tmpdir, quick = TRUE)
   })
 
-  expect_true(sum(grepl(
+  expect_true(sum(cli::ansi_grepl(
     paste0(
       paste(.message$LoadedCache(.message$LoadedCacheResult(), "quickFun"), .message$AddingToMemoised), "|",
       .message$LoadedCache(.message$LoadedCacheResult("Memoised"), "quickFun")
@@ -375,7 +371,7 @@ test_that("test 'quick' argument", {
   mess1 <- capture_messages({
     out1c <- Cache(quickFun, r1, cachePath = tmpdir, quick = TRUE)
   })
-  expect_true(sum(grepl(
+  expect_true(sum(cli::ansi_grepl(
     paste0(
       paste(.message$LoadedCache(.message$LoadedCacheResult(), "quickFun"), .message$AddingToMemoised), "|",
       paste(.message$LoadedCacheResult("Memoised"), "quickFun call")
@@ -384,6 +380,7 @@ test_that("test 'quick' argument", {
   )) == 0)
 
   # mess3 <- capture_messages({ out1c <- Cache(quickFun, r1, cachePath = tmpdir, quick = FALSE) })
+  # Should be "\033[34mSaved! Cache file: d3d8d40b1aeba01e.rds; fn: \033[31mquickFun\033[34m\033[39m\n"
   mess <- capture_messages({
     out1c <- Cache(quickFun, r1, cachePath = tmpdir, quick = FALSE)
   })
@@ -534,13 +531,13 @@ test_that("test asPath", {
   a1 <- capture_messages(Cache(saveRDS, obj, file = "filename.RData", cachePath = tmpdir))
   # Second -- has a filename.RData, and passing a character string,
   #           it tries to see if it is a file, if yes, it digests it
-  a2 <- capture_messages(Cache(saveRDS, obj, file = "filename.RData", cachePath = tmpdir))
+  a2 <- capture_messages(Cache(saveRDS, obj, file = asPath("filename.RData"), cachePath = tmpdir))
   # Third -- finally has all same as second time
-  a3 <- capture_messages(Cache(saveRDS, obj, file = "filename.RData", cachePath = tmpdir))
+  a3 <- capture_messages(Cache(saveRDS, obj, file = asPath("filename.RData"), cachePath = tmpdir))
 
   expect_equal(length(a1), 1)
   expect_equal(length(a2), 1)
-  expect_true(sum(grepl(paste(
+  expect_true(sum(cli::ansi_grepl(paste(
     .message$LoadedCacheResult("Memoised"), "|",
     .message$LoadedCacheResult()
   ), a3)) == 1)
@@ -560,11 +557,11 @@ test_that("test asPath", {
                                quick = TRUE, cachePath = tmpdir
   ))
   expect_equal(length(a1), 1)
-  expect_true(sum(grepl(paste(
+  expect_true(sum(cli::ansi_grepl(paste(
     .message$LoadedCacheResult("Memoised"), "|",
     .message$LoadedCacheResult()
   ), a2)) == 1)
-  expect_true(sum(grepl(paste(.message$LoadedCacheResult("Memoised"), "saveRDS call"), a3)) == 1)
+  expect_true(sum(cli::ansi_grepl(paste(.message$LoadedCacheResult("Memoised"), "saveRDS call"), a3)) == 1)
 
   unlink("filename.RData")
   try(clearCache(tmpdir, ask = FALSE), silent = TRUE)
@@ -581,11 +578,11 @@ test_that("test asPath", {
                                quick = TRUE, cachePath = tmpdir
   ))
   expect_equal(length(a1), 1)
-  expect_true(sum(grepl(paste(
+  expect_true(sum(cli::ansi_grepl(paste(
     .message$LoadedCacheResult("Memoised"), "|",
     .message$LoadedCacheResult()
   ), a2)) == 1)
-  expect_true(sum(grepl(paste(.message$LoadedCacheResult("Memoised"), "saveRDS call"), a3)) == 1)
+  expect_true(sum(cli::ansi_grepl(paste(.message$LoadedCacheResult("Memoised"), "saveRDS call"), a3)) == 1)
 })
 
 test_that("test wrong ways of calling Cache", {
@@ -609,205 +606,6 @@ test_that("test quoted FUN in Cache", {
   expect_true(all.equalWONewCache(A, C))
 })
 
-test_that("test Cache argument inheritance to inner functions", {
-  testInit("terra",
-           verbose = TRUE,
-           opts = list(
-             "reproducible.showSimilar" = FALSE,
-             "reproducible.useMemoise" = FALSE
-           )
-  )
-  opts <- options(reproducible.cachePath = tmpdir)
-  on.exit(options(opts), add = TRUE)
-  tmpDirFiles <- dir(tempdir())
-  on.exit(
-    {
-      newOnes <- setdiff(tmpDirFiles, dir(tempdir()))
-      unlink(newOnes, recursive = TRUE)
-    },
-    add = TRUE
-  )
-
-  outer <- function(n, not = NULL) {
-    Cache(rnorm, n, notOlderThan = not)
-  }
-
-  mess <- capture_messages(Cache(outer, n = 2))
-  expect_equal(sum(grepl(.message$NoCacheRepoSuppliedGrep, mess)), 2)
-  clearCache(ask = FALSE, x = tmpdir)
-
-  # options(reproducible.cachePath = tmpCache)
-  out <- capture_messages(Cache(outer, n = 2))
-  expect_true(all(unlist(lapply(
-    c(.message$NoCacheRepoSuppliedGrep, .message$NoCacheRepoSuppliedGrep),
-    function(mess) any(grepl(mess, out))
-  ))))
-
-  # does Sys.time() propagate to outer ones
-  out <- capture_messages(Cache(outer(n = 2, not = Sys.time() + 1), notOlderThan = Sys.time() + 1))
-  expect_equal(sum(grepl(.message$NoCacheRepoSuppliedGrep, out)), 2)
-
-  # does Sys.time() propagate to outer ones -- no message about cachePath being tempdir()
-  mess <- capture_messages(Cache(outer(n = 2, not = Sys.time()), notOlderThan = Sys.time(), cachePath = tmpdir))
-  expect_equal(sum(grepl(.message$NoCacheRepoSuppliedGrep, mess)), 1)
-
-  # does cachePath propagate to outer ones -- no message about cachePath being tempdir()
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir))
-  expect_true(length(out) == 2)
-  expect_true(sum(grepl(paste(.message$LoadedCacheResult(), "outer call"), out)) == 1)
-
-  # check that the rnorm inside "outer" returns cached value even if outer "outer" function is changed
-  outer <- function(n) {
-    a <- 1
-    Cache(rnorm, n)
-  }
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir))
-  expect_true(length(out) == 4)
-  msgGrep <- paste(paste(.message$LoadedCacheResult(), "rnorm call"),
-                   "There is no similar item in the cachePath",
-                   sep = "|"
-  )
-  expect_true(sum(grepl(msgGrep, out)) == 1)
-
-  # Override with explicit argument
-  outer <- function(n) {
-    a <- 1
-    Cache(rnorm, n, notOlderThan = Sys.time() + 1)
-  }
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir))
-  expect_equal(sum(grepl(.message$NoCacheRepoSuppliedGrep, out)), 1)
-
-  # change the outer function, so no cache on that, & have notOlderThan on rnorm,
-  #    so no Cache on that
-  outer <- function(n) {
-    b <- 1
-    Cache(rnorm, n, notOlderThan = Sys.time() + 1)
-  }
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir))
-  expect_equal(sum(grepl(.message$NoCacheRepoSuppliedGrep, out)), 1)
-
-  # expect_true(all(grepl("There is no similar item in the cachePath", out)))
-  # Second time will get a cache on outer
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir))
-  expect_true(length(out) == 2)
-  expect_true(sum(grepl(paste(.message$LoadedCacheResult(), "outer call"), out)) == 1)
-
-  # doubly nested
-  inner <- function(mean, useCache = TRUE) {
-    d <- 1
-    Cache(rnorm, n = 3, mean = mean, useCache = useCache)
-  }
-  outer <- function(n, useCache = TRUE, ...) {
-    Cache(inner, 0.1, useCache = useCache, ...)
-  }
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir))
-
-  outer <- function(n) {
-    Cache(inner, 0.1, notOlderThan = Sys.time() - 1e4)
-  }
-
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir, notOlderThan = Sys.time()))
-  msgGrep <- paste(paste(.message$LoadedCacheResult(), "inner call"),
-                   "There is no similar item in the cachePath",
-                   sep = "|"
-  )
-  expect_true(sum(grepl(.message$NoCacheRepoSuppliedGrep, out)) == 1)
-
-  # expect_true(sum(grepl(msgGrep, out)) == 1)
-
-  outer <- function(n) {
-    Cache(inner, 0.1, notOlderThan = Sys.time())
-  }
-  inner <- function(mean) {
-    d <- 1
-    Cache(rnorm, n = 3, mean = mean, notOlderThan = Sys.time() - 1e5)
-  }
-
-  out <- capture_messages(Cache(outer, n = 2, cachePath = tmpdir, notOlderThan = Sys.time()))
-  msgGrep <- paste(paste(.message$LoadedCacheResult(), "rnorm call"),
-                   "There is no similar item in the cachePath",
-                   sep = "|"
-  )
-  expect_true(sum(grepl(msgGrep, out)) == 1)
-
-  # Check userTags -- all items have it
-  clearCache(tmpdir, ask = FALSE)
-  outerTag <- "howdie"
-  aa <- Cache(outer, n = 2, cachePath = tmpdir, userTags = outerTag)
-  bb <- showCache(tmpdir, userTags = outerTag)
-  cc <- showCache(tmpdir)
-  data.table::setorderv(bb, c(.cacheTableHashColName(), "tagKey", "tagValue"))
-  data.table::setorderv(cc, c(.cacheTableHashColName(), "tagKey", "tagValue"))
-  expect_true(identical(bb, cc))
-
-  # Check userTags -- all items have the outer tag propagate, plus inner ones only have inner ones
-  innerTag <- "notHowdie"
-  inner <- function(mean) {
-    d <- 1
-    Cache(rnorm, n = 3, mean = mean, notOlderThan = Sys.time() - 1e5, userTags = innerTag)
-  }
-
-  clearCache(tmpdir, ask = FALSE)
-  aa <- Cache(outer, n = 2, cachePath = tmpdir, userTags = outerTag)
-  bb <- showCache(tmpdir, userTags = outerTag)
-  cc <- showCache(tmpdir)
-  data.table::setorderv(cc)
-  data.table::setorderv(bb)
-  expect_true(identical(bb, cc))
-
-  #
-  bb <- showCache(tmpdir, userTags = "notHowdie")
-  cc <- showCache(tmpdir)
-  data.table::setorderv(cc)
-  data.table::setorderv(bb)
-  expect_false(identical(bb, cc))
-  expect_true(length(unique(bb[[.cacheTableHashColName()]])) == 1)
-  expect_true(length(unique(cc[[.cacheTableHashColName()]])) == 3)
-})
-
-test_that("test future", {
-  skip_on_cran()
-  skip_on_ci()
-  # skip_if_not_installed("future")
-
-  .onLinux <- .Platform$OS.type == "unix" && unname(Sys.info()["sysname"]) == "Linux"
-  # if (.onLinux) {
-  testInit(c("terra", "future"),
-           verbose = TRUE, tmpFileExt = ".rds",
-           opts = list(
-             "future.supportsMulticore.unstable" = "quiet",
-             "reproducible.futurePlan" = "multicore"
-           )
-  )
-
-  # There is now a warning with future package
-  a <- list()
-  (aa <- system.time({
-    for (i in c(1:3)) a[[i]] <- Cache(cachePath = tmpCache, rnorm, 1e6 + i)
-  }))
-  sca <- showCache(tmpCache)
-  expect_true(length(unique(sca[[.cacheTableHashColName()]])) == 3)
-
-  try(unlink(tmpCache, recursive = TRUE))
-  b <- list()
-  (bb <- system.time({
-    for (i in 1:3) b[[i]] <- Cache(cachePath = tmpCache, rnorm(1e6 + i))
-  }))
-  bb <- showCache(tmpCache)
-  expect_true(length(unique(bb[[.cacheTableHashColName()]])) == 3)
-
-  # Test the speed of rerunning same line
-  d <- list()
-  (dd <- system.time({
-    for (i in 1:3) d[[i]] <- Cache(cachePath = tmpCache, rnorm(1e6 + i))
-  }))
-  expect_true((dd[[3]] * 3) < aa[[3]])
-  for (i in 1:3) {
-    expect_true(identical(attr(d[[i]], ".Cache")$newCache, FALSE))
-  }
-  # }
-})
-
 test_that("test mergeCache", {
   testInit("data.table", verbose = TRUE)
 
@@ -843,7 +641,7 @@ test_that("test mergeCache", {
   mess <- capture_messages({
     d1 <- mergeCache(tmpCache, tmpdir)
   })
-  expect_true(any(grepl("Skipping", mess)))
+  expect_true(any(cli::ansi_grepl("Skipping", mess)))
   expect_true(identical(showCache(d), showCache(d1)))
 })
 
@@ -907,7 +705,7 @@ test_that("test cache-helpers", {
   bnfn3 <- basename(fn3[actualFiles])
   bnfn2 <- unique(filePathSansExt(bnfn2))
   bnfn3 <- unique(filePathSansExt(bnfn3))
-  sameFileBase <- grepl(pattern = bnfn2, x = bnfn3)
+  sameFileBase <- cli::ansi_grepl(pattern = bnfn2, x = bnfn3)
   expect_true(sameFileBase)
 
   unlink(Filenames(s2))
@@ -927,7 +725,7 @@ test_that("test useCache = 'overwrite'", {
     b <- Cache(rnorm, 1, useCache = "overwrite", cachePath = tmpCache)
   })
   expect_true(!identical(a, b))
-  expect_true(any(grepl(pattern = "Overwriting", mess)))
+  expect_true(any(cli::ansi_grepl(pattern = "Overwriting", mess)))
 
   clearCache(x = tmpCache, ask = FALSE)
 
@@ -942,14 +740,14 @@ test_that("test useCache = 'overwrite'", {
     b <- Cache(rnorm, 1, cachePath = tmpCache)
   })
   expect_true(!identical(a, b))
-  expect_true(any(grepl(pattern = "Overwriting", mess)))
+  expect_true(any(cli::ansi_grepl(pattern = "Overwriting", mess)))
 })
 
 test_that("test rm large non-file-backed rasters", {
   ## This is a large object test!
   skip_on_cran()
   if (!is.null(getOption("reproducible.conn", NULL))) {
-    if (!grepl("SQLite", class(getOption("reproducible.conn", NULL)))) {
+    if (!cli::ansi_grepl("SQLite", class(getOption("reproducible.conn", NULL)))) {
       skip("This is not for non-SQLite")
     }
   }
@@ -996,28 +794,7 @@ test_that("test cc", {
   expect_true(length(unique(b1[[.cacheTableHashColName()]])) == 0)
 
   mess <- capture_messages(cc(ask = FALSE, x = tmpCache)) # Cache is already empty
-  expect_true(any(grepl("Cache already empty", mess)))
-})
-
-test_that("test pre-creating conn", {
-  if (!useDBI()) skip("Only relevant for DBI backend")
-  testInit("terra", ask = FALSE, tmpFileExt = c(".tif", ".tif"))
-  on.exit({
-    DBI::dbDisconnect(conn)
-  })
-
-  conn <- dbConnectAll(cachePath = tmpdir, conn = NULL)
-  ra <- terra::rast(terra::ext(0, 10, 0, 10), vals = sample(1:100))
-  rb <- terra::rast(terra::ext(0, 10, 0, 10), vals = sample(1:100))
-  r1 <- Cache(.writeRaster, ra, filename = tmpfile[1], overwrite = TRUE, cachePath = tmpCache)
-  r2 <- Cache(.writeRaster, rb,
-              filename = tmpfile[2], overwrite = TRUE, cachePath = tmpdir,
-              conn = conn
-  )
-  expect_true(file.exists(Filenames(r1)))
-  expect_true(file.exists(Filenames(r2)))
-  expect_false(grepl(basename(dirname(Filenames(r1))), "rasters")) # changed behaviour as of reproducible 1.2.0.9020
-  expect_false(grepl(basename(dirname(Filenames(r2))), "rasters")) # changed behaviour as of reproducible 1.2.0.9020
+  expect_true(any(cli::ansi_grepl("Cache already empty", mess)))
 })
 
 test_that("test .defaultUserTags", {
@@ -1031,30 +808,6 @@ test_that("test .defaultUserTags", {
   expect_false(anyNewTags)
 })
 
-test_that("test failed Cache recovery -- message to delete cacheId", {
-  if (!useDBI()) skip("Not relevant for multipleDBfiles")
-  testInit(opts = list("reproducible.useMemoise" = FALSE))
-
-  b <- Cache(rnorm, 1, cachePath = tmpdir)
-  sc <- showCache(tmpdir)
-  ci <- unique(sc[[.cacheTableHashColName()]])
-  unlink(CacheStoredFile(tmpdir, ci))
-
-
-  rm(b)
-  mess <- capture_messages({
-    warn <- capture_warnings({
-      err <- capture_error({
-        d <- Cache(rnorm, 1, cachePath = tmpdir)
-      })
-    })
-  })
-  expect_true(sum(grepl(paste0("(trying to recover).*(", ci, ")"), mess)) == 1)
-  expect_true(sum(grepl(paste0("(trying to recover).*(", ci, ")"), err)) == 0)
-  expect_true(any(grepl(paste0("[cannot|failed to] open"), paste(warn, err, mess))))
-  expect_true(is.numeric(d))
-})
-
 test_that("test changing reproducible.cacheSaveFormat midstream", {
   skip_if_not_installed("qs")
 
@@ -1072,14 +825,14 @@ test_that("test changing reproducible.cacheSaveFormat midstream", {
     b <- Cache(rnorm, 1, cachePath = tmpdir)
   })
   expect_false(attr(b, ".Cache")$newCache)
-  expect_true(sum(grepl("Changing format of Cache entry from rds to qs", mess)) == 1)
+  expect_true(sum(cli::ansi_grepl("Changing format of Cache entry from rds to qs", mess)) == 1)
 
   opts <- options(reproducible.cacheSaveFormat = "rds")
   mess <- capture_messages({
     b <- Cache(rnorm, 1, cachePath = tmpdir)
   })
   expect_false(attr(b, ".Cache")$newCache)
-  expect_true(sum(grepl("Changing format of Cache entry from qs to rds", mess)) == 1)
+  expect_true(sum(cli::ansi_grepl("Changing format of Cache entry from qs to rds", mess)) == 1)
 })
 
 test_that("test file link with duplicate Cache", {
@@ -1114,7 +867,7 @@ test_that("test file link with duplicate Cache", {
     g <- Cache(sam1, N, cachePath = tmpCache)
   })
 
-  expect_true(sum(grepl("A file with identical", mess3)) == 1)
+  expect_true(sum(cli::ansi_grepl("A file with identical", mess3)) == 1)
 
   set.seed(123)
   mess1 <- capture_messages({
@@ -1130,8 +883,8 @@ test_that("test file link with duplicate Cache", {
   mess2 <- capture_messages({
     d <- Cache(sam1, N, cachePath = tmpCache)
   })
-  expect_true(any(grepl(.message$LoadedCacheResult(), mess2)))
-  expect_true(any(grepl(.message$LoadedCacheResult(), mess1)))
+  expect_true(any(cli::ansi_grepl(.message$LoadedCacheResult(), mess2)))
+  expect_true(any(cli::ansi_grepl(.message$LoadedCacheResult(), mess1)))
   # There are intermittent "status 5" warnings on next line on Windows -- not relevant here
   warns <- capture_warnings({
     out1 <- try(system2("du", paste0("\"", tmpCache, "\""), stdout = TRUE), silent = TRUE)
@@ -1234,14 +987,14 @@ test_that("quick arg in Cache as character", {
     ranRas <- terra::rast(terra::ext(0, 10, 0, 10), vals = vals)
     ranRas <- suppressWarningsSpecific(
       falseWarnings = proj6Warn,
-      writeRaster(ranRas, filename = tf2, overwrite = TRUE)
+      writeRaster(ranRas, filename = asPath(tf2), overwrite = TRUE)
     )
     a <- sample(1e7, 1)
     saveRDS(a, file = tf)
 
     # new copy
     messes[[i]] <- capture_messages(Cache(saveRDS, ranRas,
-                                          file = tf, cachePath = tmpCache,
+                                          file = asPath(tf), cachePath = tmpCache,
                                           quick = quicks[[i]]
     ))
   }
@@ -1717,7 +1470,7 @@ test_that("Issue 316 - writeOutputs in a non getwd dir", {
   rasterToMatchLarge <- list()
   for (i in 1:2) {
     rasterToMatchLarge[[i]] <- Cache(writeOutputs, rasterToMatch,
-                                     filename2 = .suffix(
+                                     writeTo = .suffix(
                                        file.path(tmpdir, "rasterToMatchLarge.tif"),
                                        paste0("_", studyAreaName)
                                      ), datatype = "INT2U",
@@ -1793,7 +1546,7 @@ test_that("terra files were creating file.link", {
     ras
   }
   mess <- capture_messages(Map(f = func, fn = tmpfile, ras = rasts))
-  expect_false(any(grepl("file.link", mess)))
+  expect_false(any(cli::ansi_grepl("file.link", mess)))
 
 })
 
@@ -1854,3 +1607,47 @@ test_that("cacheId = 'previous'", {
   e <- rnorm(4) |> Cache(.functionName = fnName, cacheId = "previous")
   expect_false(unlist(attr(e, ".Cache")))
 })
+
+
+
+test_that("test omitArgs = 'x', #400", {
+  skip_if_not_installed("terra")
+  testInit("terra")
+
+  wkt <- c("MULTIPOLYGON ( ((40 40, 20 45, 45 30, 40 40)),
+((20 35, 10 30, 10 10, 30 5, 45 20, 20 35),(30 20, 20 15, 20 25, 30 20)))",
+           "POLYGON ((0 -5, 10 0, 10 -10, 0 -5))")
+  w <- terra::vect(wkt)
+
+  ## fails - ommitting x arg
+  testthat::expect_no_error(Cache(centroids,
+                                  x = w,
+                                  omitArgs = c("x")))
+
+})
+
+
+test_that("cacheId = 'customName'", {
+  testInit()
+  opts <- options(reproducible.cachePath = tmpdir)
+  on.exit(options(opts), add = TRUE)
+
+  fnName <- "rnorm_this_one"
+  d <- rnorm(2) |> Cache(.functionName = fnName, cacheId = "myCacheObj")
+  e <- rnorm(3) |> Cache(.functionName = fnName, cacheId = "myCacheObj")
+  expect_true(all.equalWONewCache(e, d))
+
+  rudbi <- getOption("reproducible.useDBI")
+
+
+  newDBI <- setdiff(c(TRUE, FALSE), rudbi)
+  opts <- options(reproducible.useDBI = newDBI)
+  on.exit(options(opts))
+
+  f <- rnorm(4) |> Cache(.functionName = fnName, cacheId = "myCacheObj")
+  g <- rnorm(5) |> Cache(.functionName = fnName, cacheId = "myCacheObj")
+  expect_true(all.equalWONewCache(e, d))
+  expect_true(all.equalWONewCache(e, f))
+  expect_true(all.equalWONewCache(e, g))
+})
+
