@@ -81,8 +81,6 @@ test_that("prepInputs doesn't work (part 1)", {
 
   unlink(dirname(ecozoneFilename), recursive = TRUE)
   # Test useCache = FALSE -- doesn't error and has no "loading from cache" or "loading from memoised"
-  # aaaa <<- 1
-  # on.exit(rm(aaaa, envir = .GlobalEnv))
   noisyOutput <- capture.output({
     warn <- suppressWarningsSpecific(
       falseWarnings = "attribute variables are assumed to be spatially constant",
@@ -95,7 +93,7 @@ test_that("prepInputs doesn't work (part 1)", {
               alsoExtract = reproducible::asPath(ecozoneFiles),
               studyArea = StudyArea,
               destinationPath = dPath,
-              filename2 = "EcozoneFile.shp",
+              writeTo = "EcozoneFile.shp",
               useCache = FALSE
             ),
             quick = "destinationPath"
@@ -118,7 +116,7 @@ test_that("prepInputs doesn't work (part 1)", {
             alsoExtract = reproducible::asPath(ecozoneFiles),
             studyArea = StudyArea,
             destinationPath = dPath,
-            filename2 = "EcozoneFile.shp",
+            writeTo = "EcozoneFile.shp",
             useCache = TRUE # with useTerra = TRUE, this is only for loading, not postProcess
           ),
           quick = "destinationPath"
@@ -168,6 +166,14 @@ test_that("prepInputs doesn't work (part 1)", {
     )
   )
   expect_true(is(shpEcozone, vectorType()))
+
+  #stops if deprecated arguments used
+  expect_error(prepInputs(destinationPath = dPath,
+                          url = "http://sis.agr.gc.ca/cansis/nsdb/ecostrat/zone/ecozone_shp.zip",
+                          archive = file.path(dPath, "ecozone_shp.zip"),
+                          studyArea = StudyArea,
+                          filename2 = "use_writeTo_instead.shp"))
+
 })
 
 test_that("interactive prepInputs", {
@@ -1673,12 +1679,21 @@ test_that("options inputPaths", {
     })
   })
   expect_true(sum(grepl(paste0(hardlinkOrSymlinkMessagePrefixForGrep), mess1)) == 1)
-  expect_true(sum(grepl(paste0(tmpdir3), mess1)) == 1)
+  expect_true(sum(grepl(paste0(tmpdir3), mess1)) == 2)
 
   # THIS NEXT ONE DOESN"T PASS ON GA on WINDOWS, skip it
   #  should copy from 2nd directory (tmpCache) because it is removed in the lower
   #  tmpdir directory & has a CHECKSUMS.txt
   if (!isTRUE(as.logical(Sys.getenv("CI")))) { # (!testthat:::on_ci()) { # can't use the :::
+
+    url_2 = if (!useGADM) url2 else f$url
+    targetFile_2 = if (useGADM) theFile else f$targetFile
+    dlFun_2 = if (useGADM) getDataFn else NULL
+    name_2 = if (useGADM) "GADM" else NULL
+    country_2 = if (useGADM) "LUX" else NULL
+    level_2 = if (useGADM) 0 else NULL
+    path_2 = if (useGADM) tmpdir else NULL
+
     options("reproducible.inputPaths" = tmpdir)
     options("reproducible.inputPathsRecursive" = TRUE)
     file.remove(file.path(tmpCache, theFile))
@@ -1686,13 +1701,13 @@ test_that("options inputPaths", {
     noisyOutput <- capture.output({
       mess1 <- capture_messages({
         test1 <- prepInputs(
-          url = if (!useGADM) url2 else f$url,
-          targetFile = if (useGADM) theFile else f$targetFile,
-          dlFun = if (useGADM) getDataFn else NULL,
-          name = if (useGADM) "GADM" else NULL,
-          country = if (useGADM) "LUX" else NULL,
-          level = if (useGADM) 0 else NULL,
-          path = if (useGADM) tmpdir else NULL,
+          url = url_2,
+          targetFile = targetFile_2,
+          dlFun = dlFun_2,
+          name = name_2,
+          country = country_2,
+          level = level_2,
+          path = path_2,
           destinationPath = tmpdir1, verbose = 3
         )
       })
@@ -1711,19 +1726,28 @@ test_that("options inputPaths", {
       "reproducible.inputPathsRecursive" = FALSE
     )
   )
+
   options("reproducible.inputPaths" = tmpdir)
   tmpdir2 <- file.path(tmpdir, rndstr(1, 5))
+  url_2 = if (!useGADM) url2 else f$url
+  targetFile_2 = if (useGADM) theFile else f$targetFile
+  dlFun_2 = if (useGADM) getDataFn else NULL
+  name_2 = if (useGADM) "GADM" else NULL
+  country_2 = if (useGADM) "LUX" else NULL
+  level_2 = if (useGADM) 0 else NULL
+  path_2 = if (useGADM) tmpdir else NULL
+
   noisyOutput <- capture.output({
     noisyOutput <- capture.output(type = "message", {
       mess1 <- capture_messages({
         test1 <- prepInputs(
-          url = if (!useGADM) url2 else f$url,
-          targetFile = if (useGADM) theFile else f$targetFile,
-          dlFun = if (useGADM) getDataFn else NULL,
-          name = if (useGADM) "GADM" else NULL,
-          country = if (useGADM) "LUX" else NULL,
-          level = if (useGADM) 0 else NULL,
-          path = if (useGADM) tmpdir else NULL,
+          url = url_2,
+          targetFile = targetFile_2,
+          dlFun = dlFun_2,
+          name = name_2,
+          country = country_2,
+          level = level_2,
+          path = path_2,
           destinationPath = tmpdir2
         )
       })
@@ -1733,23 +1757,31 @@ test_that("options inputPaths", {
   # Must remove the link that happens during downloading to a .tempPath
   test10 <- grep(hardlinkOrSymlinkMessagePrefixForGrep, mess1, value = TRUE)
   test10 <- grep(tmpdir2, test10, invert = TRUE, value = TRUE)
-  expect_true(length(test10) == (1 - useGADM)) #
+  expect_true(length(test10) == (1)) #
 
   # Have file in inputPath, not in destinationPath
   unlink(file.path(tmpdir2, theFile))
   expect_false(file.exists(file.path(tmpdir2, theFile))) # FALSE -- confirm previous line
   expect_true(file.exists(file.path(tmpdir, theFile))) # TRUE b/c is in getOption('reproducible.inputPaths')
   tmpdir2 <- file.path(tmpdir, rndstr(1, 5))
+  url_2 = if (!useGADM) url2 else f$url
+  targetFile_2 = if (useGADM) theFile else f$targetFile
+  dlFun_2 = if (useGADM) getDataFn else NULL
+  name_2 = if (useGADM) "GADM" else NULL
+  country_2 = if (useGADM) "LUX" else NULL
+  level_2 = if (useGADM) 0 else NULL
+  path_2 = if (useGADM) tmpdir else NULL
+
   noisyOutput <- capture.output({
     mess1 <- capture_messages({
       test1 <- prepInputs(
-        url = if (!useGADM) url2 else f$url,
-        targetFile = if (useGADM) theFile else f$targetFile,
-        dlFun = if (useGADM) getDataFn else NULL,
-        name = if (useGADM) "GADM" else NULL,
-        country = if (useGADM) "LUX" else NULL,
-        level = if (useGADM) 0 else NULL,
-        path = if (useGADM) tmpdir else NULL,
+        url = url_2,
+        targetFile = targetFile_2,
+        dlFun = dlFun_2,
+        name = name_2,
+        country = country_2,
+        level = level_2,
+        path = path_2,
         destinationPath = tmpdir2, verbose = 3
       )
     })
@@ -1762,16 +1794,23 @@ test_that("options inputPaths", {
   unlink(file.path(tmpdir, theFile))
   expect_false(file.exists(file.path(tmpdir, theFile))) # FALSE -- confirm previous line
   expect_true(file.exists(file.path(tmpdir2, theFile))) # TRUE b/c is in getOption('reproducible.inputPaths')
+  url_2 = if (!useGADM) url2 else f$url
+  targetFile_2 = if (useGADM) theFile else f$targetFile
+  dlFun_2 = if (useGADM) getDataFn else NULL
+  name_2 = if (useGADM) "GADM" else NULL
+  country_2 = if (useGADM) "LUX" else NULL
+  level_2 = if (useGADM) 0 else NULL
+  path_2 = if (useGADM) tmpdir else NULL
   noisyOutput <- capture.output({
     mess1 <- capture_messages({
       test1 <- prepInputs(
-        url = if (!useGADM) url2 else f$url,
-        targetFile = if (useGADM) theFile else f$targetFile,
-        dlFun = if (useGADM) getDataFn else NULL,
-        name = if (useGADM) "GADM" else NULL,
-        country = if (useGADM) "LUX" else NULL,
-        level = if (useGADM) 0 else NULL,
-        path = if (useGADM) tmpdir else NULL,
+        url = url_2,
+        targetFile = targetFile_2,
+        dlFun = dlFun_2,
+        name = name_2,
+        country = country_2,
+        level = level_2,
+        path = path_2,
         destinationPath = tmpdir2, verbose = 2
       )
     })
@@ -1785,17 +1824,24 @@ test_that("options inputPaths", {
   expect_false(file.exists(file.path(tmpdir, theFile))) # FALSE -- confirm previous line
   expect_false(file.exists(file.path(tmpdir2, theFile))) # TRUE b/c is in getOption('reproducible.inputPaths')
   options("reproducible.inputPaths" = tmpdir)
+  url_2 = if (!useGADM) url2 else f$url
+  targetFile_2 = if (useGADM) theFile else f$targetFile
+  dlFun_2 = if (useGADM) getDataFn else NULL
+  name_2 = if (useGADM) "GADM" else NULL
+  country_2 = if (useGADM) "LUX" else NULL
+  level_2 = if (useGADM) 0 else NULL
+  path_2 = if (useGADM) tmpdir else NULL
   noisyOutput <- capture.output({
     noisyOutput <- capture.output(type = "message", {
       mess1 <- capture_messages({
         test1 <- prepInputs(
-          url = if (!useGADM) url2 else f$url,
-          targetFile = if (useGADM) theFile else f$targetFile,
-          dlFun = if (useGADM) getDataFn else NULL,
-          name = if (useGADM) "GADM" else NULL,
-          country = if (useGADM) "LUX" else NULL,
-          level = if (useGADM) 0 else NULL,
-          path = if (useGADM) tmpdir else NULL,
+          url = url_2,
+          targetFile = targetFile_2,
+          dlFun = dlFun_2,
+          name = name_2,
+          country = country_2,
+          level = level_2,
+          path = path_2,
           destinationPath = tmpdir, verbose = 2
         )
       })
@@ -1826,7 +1872,7 @@ test_that("writeOutputs saves factor rasters with .grd class to preserve levels"
   tifTmp <- normPath(tifTmp)
 
   b1 <- suppressWarnings(terra::writeRaster(a, filename = tifTmp, overwrite = TRUE)) # the GDAL>6 issue
-  b1a <- writeOutputs(a, filename2 = tifTmp)
+  b1a <- writeOutputs(a, writeTo = tifTmp)
   expect_equivalent(b1, b1a)
   expect_equivalent(b1[], b1a[])
 
@@ -1863,7 +1909,7 @@ test_that("rasters aren't properly resampled", {
       targetFile = tiftemp1, rasterToMatch = terra::rast(tiftemp2),
       destinationPath = dirname(tiftemp1), method = "bilinear",
       datatype = "INT2S",
-      filename2 = tempfile(tmpdir = tmpdir, fileext = ".tif")
+      writeTo = tempfile(tmpdir = tmpdir, fileext = ".tif")
     )
   }) # about "raster layer has integer values"
 
@@ -1879,7 +1925,7 @@ test_that("rasters aren't properly resampled", {
     out3 <- prepInputs(
       targetFile = tiftemp3, rasterToMatch = terra::rast(tiftemp2),
       destinationPath = dirname(tiftemp3),
-      filename2 = tempfile(tmpdir = tmpdir, fileext = ".tif")
+      writeTo = tempfile(tmpdir = tmpdir, fileext = ".tif")
     )
     expect_true(dataType2(out3) == "FLT4S")
 
@@ -1894,7 +1940,7 @@ test_that("rasters aren't properly resampled", {
     out3 <- prepInputs(
       targetFile = tiftemp4, rasterToMatch = terra::rast(tiftemp2),
       destinationPath = dirname(tiftemp3),
-      filename2 = tempfile(tmpdir = tmpdir, fileext = ".tif")
+      writeTo = tempfile(tmpdir = tmpdir, fileext = ".tif")
     )
     expect_true(is(out3, rasterType()))
     expect_true(identical(length(Filenames(out3)), 1L))
@@ -1907,7 +1953,7 @@ test_that("rasters aren't properly resampled", {
           targetFile = tiftemp4, rasterToMatch = terra::rast(tiftemp2),
           destinationPath = dirname(tiftemp3),
           fun = rasterStackFn,
-          filename2 = c(
+          writeTo = c(
             tempfile(tmpdir = tmpdir, fileext = ".grd"),
             tempfile(tmpdir = tmpdir, fileext = ".grd")
           )
@@ -1931,7 +1977,7 @@ test_that("rasters aren't properly resampled", {
           targetFile = tiftemp5, rasterToMatch = terra::rast(tiftemp2),
           destinationPath = dirname(tiftemp3),
           fun = rasterStackFn,
-          filename2 = c(
+          writeTo = c(
             tempfile(tmpdir = tmpdir, fileext = ".grd"),
             tempfile(tmpdir = tmpdir, fileext = ".grd"),
             tempfile(tmpdir = tmpdir, fileext = ".tif")
@@ -1947,7 +1993,7 @@ test_that("rasters aren't properly resampled", {
           targetFile = tiftemp4, rasterToMatch = terra::rast(tiftemp2),
           destinationPath = dirname(tiftemp3),
           fun = rasterStackFn,
-          filename2 = c(
+          writeTo = c(
             tempfile(tmpdir = tmpdir, fileext = ".grd"),
             tempfile(tmpdir = tmpdir, fileext = ".grd")
           )
